/******************************************************************************
 *
 * Copyright:
 *    (C) 2005 Embedded Artists AB
 *
 * File:
 *    i2c.c
 *
 * Description:
 *    Implements a generic I2C function library for the LPC2xxx processor.
 *
 *****************************************************************************/

/******************************************************************************
 * Includes
 *****************************************************************************/
#include "i2c.h"
#include <lpc2xxx.h>
#include <config.h>


/******************************************************************************
 * Defines and typedefs
 *****************************************************************************/
#define CRYSTAL_FREQUENCY FOSC
#define PLL_FACTOR        PLL_MUL
#define VPBDIV_FACTOR     PBSD

//different modes
#define I2C_MODE_ACK0 0
#define I2C_MODE_ACK1 1
#define I2C_MODE_READ 2

/******************************************************************************
 *
 * Description:
 *    Waits till slave device returns ACK (after busy period)
 *
 * Params:
 *    [in] addr  - address
 *
 * Returns:
 *    I2C_CODE_OK or I2C_CODE_ERROR
 *
 *****************************************************************************/
tS8
i2cPoll(tU8 addr)
{
  tS8 retCode  = I2C_CODE_OK;
  tU8 status   = 0;
  volatile tU8 deviceReady = FALSE;

  while(deviceReady == FALSE)
  {
    //Generate Start condition
    retCode = i2cStart();

    //Transmit SLA+W
    if(retCode == I2C_CODE_OK)
    {
      //write SLA+W
      retCode = i2cPutChar(addr);
      while(retCode == (tS8)I2C_CODE_BUSY)
        retCode = i2cPutChar(addr);
    }

    if(retCode == I2C_CODE_OK)
    {
      //Wait until SLA+W transmitted
      //Get new status
      status = i2cCheckStatus();

      if(status == 0x18)
      {
        //data transmitted and ACK received
        deviceReady = TRUE;
      }
      else if(status == 0x20)
      {
        //data transmitted and ACK not received
        //send start bit, start again
        deviceReady = FALSE;
      }
      else if( status != 0xf8 )
      {
        //error
        retCode = I2C_CODE_ERROR;
        deviceReady = TRUE;
      }
    }

    //Generate Stop condition
    i2cStop();
  }

  return retCode;
}

