/******************************************************************************
 *
 * Copyright:
 *    (C) 2000 - 2005 Embedded Artists AB
 *
 * Description:
 *    Framework for ARM7 processor
 *
 *****************************************************************************/
#ifndef _config_h_
#define _config_h_


/******************************************************************************
 * Defines, macros, and typedefs
 *****************************************************************************/

#define FOSC 14745600                 /* External clock input frequency (must be between 10 MHz and 25 MHz) */

#define USE_PLL 1                     /* 0 = do not use on-chip PLL,
                                         1 = use on-chip PLL) */
#define PLL_MUL 4                     /* PLL multiplication factor (1 to 32) */
#define PLL_DIV 2                     /* PLL division factor (1, 2, 4, or 8) */
#define PBSD    4                     /* Peripheral bus speed divider (1, 2, or 4) */

/* initialize the MAM (Memory Accelerator Module) */
#if (FOSC * PLL_MUL) < 20000000
#define MAM_TIMING   1                /* number of CCLK to read from the FLASH */
#elif (FOSC * PLL_MUL) < 40000000
#define MAM_TIMING   2                /* number of CCLK to read from the FLASH */
#else
#define MAM_TIMING   3                /* number of CCLK to read from the FLASH */
#endif
#define MAM_SETTING  2                /* 0=disabled,
                                         1=partly enabled (enabled for code prefetch, but not for data),
                                         2=fully enabled */

#define IRQ_HANDLER  1                /* 0 = Jump to common IRQ handler
                                         1 = Load vector directly from VIC, i.e., LDR PC,[PC,#-0xFF0] */

/*initialize the exception vector mapping */
#define MAM_MAP      2                  /* 1 = exception vectors are in FLASH at 0x0000 0000,
                                           2 = exception vectors are in SRAM at 0x4000 0000   */

/*
 * CHIP        SRAM SIZE     SRAM START ADDRESS
 * LPC2104      16 * 1024     0x40000000
 * LPC2105      32 * 1024     0x40000000
 * LPC2106      64 * 1024     0x40000000
 * LPC2114      16 * 1024     0x40000000
 * LPC2119      16 * 1024     0x40000000
 * LPC2124      16 * 1024     0x40000000
 * LPC2129      16 * 1024     0x40000000
 * LPC2194      16 * 1024     0x40000000
 * LPC2131       8 * 1024     0x40000000
 * LPC2132      16 * 1024     0x40000000
 * LPC2134      16 * 1024     0x40000000
 * LPC2136      32 * 1024     0x40000000
 * LPC2138      32 * 1024     0x40000000
 * LPC2210      16 * 1024     0x40000000
 * LPC2214      16 * 1024     0x40000000
 * LPC2220      64 * 1024     0x40000000
 * LPC2290      16 * 1024     0x40000000
 * LPC2292      16 * 1024     0x40000000
 * LPC2294      16 * 1024     0x40000000
 */
#define SRAM_SADDR   0x40000000               /* SRAM starting address */
#define SRAM_SIZE    (32 * 1024)              /* LPC2138 */
#define SRAM_TOP     (SRAM_SADDR+SRAM_SIZE)   /* SRAM end address + 1 */
#define SRAM_EADDR   (SRAM_SADDR+SRAM_SIZE-1) /* SRAM end address */

#define stackSize_SYS    600
#define stackSize_SVC     64
#define stackSize_UND     64
#define stackSize_ABT     64
#define stackSize_IRQ    600
#define stackSize_FIQ     64

#define STK_SIZE      (stackSize_SYS+stackSize_SVC+stackSize_UND+stackSize_ABT+stackSize_IRQ+stackSize_FIQ)
#define STK_SADDR     (SRAM_EADDR+1-STK_SIZE)  /* Stack start address */


#define CONSOL_UART              0
#define CONSOL_BITRATE      115200
/*#define USE_UART_FIFO             FALSE  */      /* Will be added in a future release */
/*#define UART_API_NONBLOCKING      FALSE  */      /* Will be added in a future release */
/*#define UART_API_NONBLOCKING_SIZE   512  */      /* Will be added in a future release */

#define USE_NEWLIB           0   /* 0 = do not use newlib (= save about 22k FLASH),
                                    1 = use newlib = full implementation of printf(), scanf(), and malloc() */
#define CONSOLE_API_PRINTF   1   /* 0 = printf() = sendString,
                                    1 = simple, own implementation of printf() */
#define CONSOLE_API_SCANF    1   /* 0 = none,
                                    1 = simple, own implementation of scanf() */

#endif  /* _config_h_ */
